# User guide
SDR Birdrec comes with a MATLAB GUI, not all settings are configurable in the GUI though. Advanced settings can be changed in the `recorder.m` script.

## Supported SDR Hardware
SDR Birdrec uses the API and runtime library [SoapySDR](https://github.com/pothosware/SoapySDR/wiki) to interface with SDR devices. As this prevents the need to interface with the driver of a device directly, SDR Birdrec can support a wide variety of SDR devices (cf. [this list](https://github.com/pothosware/SoapySDR/wiki/FAQ#what-devices-are-supported)). It should be noted though that during development a [USRP B200](https://www.ettus.com/product/details/UB200-KIT) was used, other devices have not been tested. The clock synchronization feature will not work with most non-USRP hardware, as the necessary 10 MHz clock and PPS inputs are not available on most other devices.

## Installation Instructions
A ZIP archive is provided with SDR Birdrec for 64-bit Windows. In addition to SDR Birdrec some other software componets must be installed. Follow these instructions:

1. Download and install the newest version of PothosSDR from [here](https://github.com/pothosware/PothosSDR/wiki/Tutorial#id1) (this package includes SoapySDR, a separate installer for just SoapySDR is currently not available). Ensure that the bin folder (example C:\Program Files\PothosSDR\bin) is on the system PATH after installation.
2. Download and install the newest version of NI-DAQmx from [here](https://www.ni.com/dataacquisition/nidaqmx.htm).
3. Download and install the Microsoft Visual C++ Redistributable for Visual Studio 2017 (x64) from [here](https://go.microsoft.com/fwlink/?LinkId=746572)
3. Download and unzip SDR Birdrec. Add the unzipped folder and the bin subfolder to the MATLAB path.

Additional steps may be required for certain SDR devices. For USRP devices the following steps must also be executed:

5. __Additional step for USRP devices: FPGA and firmware images installation__
For USRP devices FPGA and firmware images must be downloaded to the directory that is specified in the `UHD_IMAGES_DIR` system environment variable. `UHD_IMAGES_DIR` is set to `C:\Program Files\PothosSDR\share\uhd\images` by default. The FPGA and firmware images can be downloaded and installed automatically with the uhd_images_downloader.py Python script (which is located at `C:\Program Files\PothosSDR\lib\uhd\utils\uhd_images_downloader.py`). If Python is not installed, this can also be done manually. First, the images must be downloaded from <http://files.ettus.com/binaries/images/>, the filename of the required file can be found in the uhd_images_downloader.py script (open it with a text editor, the filename is specified in the `_AUTOGEN_IMAGES_FILENAME` variable at the beginning of the script). Secondly, the ZIP file must be unpacked into the directory specified in `UHD_IMAGES_DIR`.

6. __Additionl step for USB USRP devices: USB driver installation__
For USRP devices with USB connection (like the USRP B200) a USB driver must be installed. Follow the steps [here](http://files.ettus.com/manual/page_transport.html#transport_usb_installwin).

The succssesful installation of an SDR device can be verified with the SoapySDRUtil command line tool (comes as part of SoapySDR). Execute the command `SoapySDRUtil --find` in the console to get a list of all detected SDR devices. Execute `SoapySDRUtil --make="driver=foo,type=bar"` (where "foo" and "bar" are replaced with actual values; e.g., `SoapySDRUtil --make="driver=uhd,type=b200"`) to test load a specific SDR device.

After SDR Birdrec is installed and its directories are on the MATLAB path, it can be started with the command `sdr_birdrec` from the MATLAB console.

## File Format
SDR Birdrec uses the W64 file format to store data. The W64 format is an extension of the WAV format that supports file sizes over 4 GiB (this is a limitation of the WAV format, which comes from the fact that it uses a 32-bit integer to store the file size in the file header). SDR Birdrec generates seven files by default (or six if no NI DAQ channels are recorded). The filenames consist of a common prefix that can be configured in the GUI and and a suffix that depends on the file:

| Filename | Description | Sample Rate |
|---------|-------------|-------------|
| `<prefix>_SdrChannelList.csv` | The SDR channel list as configured in the GUI. | - |
| `<prefix>_SdrChannels.w64` | The demodulated SDR channels. | \(r_\text{LF}\) |
| `<prefix>_SdrCarrierFreq.w64` | The estimated carrier frequencies \(f_c\) for all SDR channels. | \(r_\text{TR}\) |
| `<prefix>_SdrReceiveFreq.w64` | The mixing frequencies \(f_r\) for all SDR channels. | \(r_\text{TR}\) |
| `<prefix>_SdrSignalStrength.w64` | The signal's power spectral density at \(f_c\) for all SDR channels. | \(r_\text{TR}\) |
| `<prefix>_DAQmxChannels.w64` | The NI DAQ channels. | \(r_\text{DAQ}\) |
| `<prefix>_log.txt` | Overflow events and runtime errors are logged in here. | - |
###

If the *Split recording files* option is selected in the GUI, the W64 files are numbered (format: `<filename>.<i_split>.w64`, where `<i_split>` starts at zero). The sample precision is `float32` by default. This can be changed to `int16` in `recorder.m`. 

## Clock Synchronization
SDR Birdrec records from two distinct devices (SDR and NI DAQ). As Windows is no realtime operating system, it can not be guaranteed that the two recordings are started at the exact same time, when they are triggered with a software command. Furthermore, by default the two devices are clocked from their own internal oscillators, which are of limited accuracy. Hence, even if the recordings are started at the exact same time, the recordings will get out of synchronizations after a while. This makes signal analysis difficult, as well-timed events appear to happen at different instances of time in the two recordings.

To get synchronization between the devices the two recordings must be triggerd with a physical signal and the clock of the devices must be derived from a common reference clock. Recordings on NI DAQ devices are internally triggered with physical trigger (rising flank), this signal can be routed to a [PFI terminal](http://zone.ni.com/reference/en-XX/help/370466AE-01/TOC18.htm). USRP radios have a [PPS input](https://files.ettus.com/manual/page_sync.html), a recording on these devices can be triggered with a rising flank on this terminal. Hence, to ensure that the recordings are started at the same time, configure the *DAQmx trigger output terminal* and select the *Start SDR on external trigger* option in the GUI and connect the two terminals with a wire.

USRP radios and most NI DAQ devices can be configured to synchronize their internal clock to an external 10 MHz clock signal. To enable clock synchronization select the *Enable external clock input on SDR* option and *Enable external clock input in DAQmx* option in the GUI and connect the reference clock signal to the respective terminal on the SDR and to the configrable *Clk input terminal* on the NI DAQ device. There exists dedicated hardware to generate and distribute such reference clock signals (e.g. [this device](https://www.ettus.com/product/details/OctoClock-G)). Alternatively, a function generator may be used, to which the SDR and NI DAQ device are connected in parallel.

## GUI overview
